==> Commons-1.0.1.1.tgz: Commons-1.0.1.1/Commons/BeanUtils/PropertyUtilsBean.php <==
<?php
/* vim: set tabstop=4 shiftwidth=4: */

/*
 * Property Utilities Bean
 * (based on org.apache.commons.beanutils.PropertyUtilsBean)
 *
 * PHP version 5
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    SVN: $Id: PropertyUtilsBean.php 293 2008-04-15 13:13:20Z whitestar $
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      File available since Release 1.0.2
 */

//namespace Commons::BeanUtils;

require_once 'Commons/Lang/Object.php';
require_once 'Commons/BeanUtils/BeanUtilsBean.php';

/*
use Commons::Lang::Object;
use Commons::BeanUtils::BeanUtilsBean;
*/

/**
 * PropertyUtilsBean
 *
 *
 * @category   PHP
 * @package    Commons.BeanUtils
 * @author     Yomei Komiya
 * @copyright  2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    Release: 1.0.1.1
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      Class available since Release 1.0.2
 */
class Commons_BeanUtils_PropertyUtilsBean extends Commons_Lang_Object {

	private $descriptorsCache = null;
	
	private $mappedDescriptorsCache = null;

	
	/**
	 * @return Commons_BeanUtils_PropertyUtilsBean
	 */
	protected static function getInstance() {
		return Commons_BeanUtils_BeanUtilsBean::getInstance()->getPropertyUtils();
	}
	
	
	/** Constructor */
	public function Commons_BeanUtils_PropertyUtilsBean() {
		$this->descriptorsCache = array();
		$this->mappedDescriptorsCache = array();
	}
	
	
	public function clearDescriptors() {
		$this->descriptorsCache = array();
		$this->mappedDescriptorsCache = array();
	}
	
	
	// TODO:

}

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * End:
 */
?>

==> Commons-1.0.2.tgz: Commons-1.0.2/Commons/BeanUtils/PropertyUtilsBean.php <==
<?php
/* vim: set tabstop=4 shiftwidth=4: */

/*
 * Property Utilities Bean
 * (based on org.apache.commons.beanutils.PropertyUtilsBean)
 *
 * PHP version 5
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    SVN: $Id: PropertyUtilsBean.php 303 2008-06-29 12:16:18Z whitestar $
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      File available since Release 1.0.2
 */

//namespace Commons::BeanUtils;

require_once 'Commons/Lang/Object.php';
//require_once 'Commons/BeanUtils/BeanUtilsBean.php';

/*
use Commons::Lang::Object;
use Commons::BeanUtils::BeanUtilsBean;
*/

/**
 * PropertyUtilsBean
 *
 *
 * @category   PHP
 * @package    Commons.BeanUtils
 * @author     Yomei Komiya
 * @copyright  2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    Release: 1.0.2
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      Class available since Release 1.0.2
 */
class Commons_BeanUtils_PropertyUtilsBean extends Commons_Lang_Object {

	private $descriptorsCache = null;
	
	private $mappedDescriptorsCache = null;

	
	/**
	 * @return Commons_BeanUtils_PropertyUtilsBean
	 */
	protected static function getInstance() {
		// TODO:
		//return Commons_BeanUtils_BeanUtilsBean::getInstance()->getPropertyUtils();
	}
	
	
	/** Constructor */
	public function Commons_BeanUtils_PropertyUtilsBean() {
		$this->descriptorsCache = array();
		$this->mappedDescriptorsCache = array();
	}
	
	
	public function clearDescriptors() {
		$this->descriptorsCache = array();
		$this->mappedDescriptorsCache = array();
	}
	
	
	// TODO:

}

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * End:
 */
?>
